pub struct GetReportsResponse {
pub payload: Option<Vec<Report>>,
pub next_token: Option<String>,
pub errors: Option<Vec<Error>>,
}Expand description
GetReportsResponse : The response for the getReports operation.
Fields
payload: Option<Vec<Report>>next_token: Option<String>Returned when the number of results exceeds pageSize. To get the next page of results, call getReports with this token as the only parameter.
errors: Option<Vec<Error>>A list of error responses returned when a request is unsuccessful.
Implementations
sourceimpl GetReportsResponse
impl GetReportsResponse
sourcepub fn new() -> GetReportsResponse
pub fn new() -> GetReportsResponse
The response for the getReports operation.